#!/bin/bash
# Author : Guth (guth@ploposor.com)
# Sources location : http://www.mailzu.net/download/MailZu_0.8RC3.tar.gz

# program name/version
softversion='0.8rc3'
softname='mailzu'

# architecture/package version
arch='noarch'
#cpu='i686'
packageversion='52.2'

# number of parallel tasks of make
#ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/etc/$softname

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
      |-----handy-ruler------------------------------------------------------|
mailzu: A simple/intuitive quarantine management interface for amavisd-new.
mailzu: 
mailzu: It allows users and administrators to view quarantined messages and
mailzu: release, request, or delete them. The interface is based on
mailzu: amavisd-new SQL reporting feature.
mailzu: features:
mailzu: Multiple amavisd-new instance support, AM.PDP protocol support,
mailzu: Web based interface, Multiple language, Multiple method authentication
mailzu: (LDAP, Active Directory, SQL, EXCHANGE 5.5 and IMAP), Quarantine can
mailzu: be sorted, User/admin/super admin managment access, ...
mailzu: MailZu is released under the GNU General Public License
EOF

# extract sources
echo "extracting ..."
srcdir="MailZu_0.8RC3"
cd $buildir
rm -rf $srcdir
tar zxf $srcdir.tar.gz || exit
cd $srcdir

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

# configure package for compilation

echo "patching ..."
patch -p1 < $buildir/mailzu_0.8RC3.patch || exit -1

echo "copying ..."

# copy the doc files

cp -a *\
 $dest/usr/share/$softname/

(
    cd $dest/usr/share/$softname/
    mv CHANGELOG LICENSE README docs \
	$dest/usr/doc/$softname-$softversion
    cp config/config.php.sample \
	config/config.php.new

)

(
    cd $dest/etc/$softname/
    ln -s ../../usr/share/$softname/config/* .
    rm config.php.new
    ln -s ../../usr/share/$softname/config/config.php .
)

# put the ZenWalk build and other needed files in the right directory
echo "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion/
cp -a $buildir/mailzu_0.8RC3.patch $dest/usr/src/$softname-$softversion/
chown -R root.root $dest/usr/src/$softname-$softversion

# make the package and move it to the build directory

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then
    # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}

config usr/share/mailzu/config/config.php

" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh



#------------------( Create The *.dep File )
echo "creating .dep ..."
echo -n "apache,php,amavisd-new" > $buildir/$package.dep

cd $dest
makepkg -l y -c n $package.tgz || exit
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

